<?php

namespace Locations\Locations\Http\Controllers;

use App\Http\Controllers\PublicApiController as PublicController;
use Locations\Locations\Interfaces\DistrictsRepositoryInterface;
use Locations\Locations\Repositories\Presenter\DistrictsItemTransformer;

/**
 * Pubic API controller class.
 */
class DistrictsPublicApiController extends PublicController
{
    /**
     * Constructor.
     *
     * @param type \Locations\Districts\Interfaces\DistrictsRepositoryInterface $districts
     *
     * @return type
     */
    public function __construct(DistrictsRepositoryInterface $districts)
    {
        $this->repository = $districts;
        parent::__construct();
    }

    /**
     * Show districts's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $districts = $this->repository
            ->setPresenter('\\Locations\\Locations\\Repositories\\Presenter\\DistrictsListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $districts['code'] = 2000;
        return response()->json($districts)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show districts.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $districts = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($districts)) {
            $districts         = $this->itemPresenter($module, new DistrictsItemTransformer);
            $districts['code'] = 2001;
            return response()->json($districts)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
