<?php

namespace Locations\Locations\Providers;

use Illuminate\Support\ServiceProvider;

class LocationsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'locations');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'locations');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('locations', function ($app) {
            return $this->app->make('Locations\Locations\Locations');
        });

// Bind Districts to repository
        $this->app->bind(
            \Locations\Locations\Interfaces\DistrictsRepositoryInterface::class,
            \Locations\Locations\Repositories\Eloquent\DistrictsRepository::class
        );
        // Bind State to repository
        $this->app->bind(
            \Locations\Locations\Interfaces\StateRepositoryInterface::class,
            \Locations\Locations\Repositories\Eloquent\StateRepository::class
        );

        $this->app->register(\Locations\Locations\Providers\AuthServiceProvider::class);
        $this->app->register(\Locations\Locations\Providers\EventServiceProvider::class);
        $this->app->register(\Locations\Locations\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['locations'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/locations.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/locations')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/locations')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
