<?php

namespace Locations\Locations\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Locations\Locations\Models\Locations;
use Request;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Locations\Locations\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot(Router $router)
    {
        parent::boot($router);

        if (Request::is('*/locations/districts/*')) {
            $router->bind('districts', function ($id) {
                $districts = $this->app->make('\Locations\Locations\Interfaces\DistrictsRepositoryInterface');
                return $districts->findorNew($id);
            });
        }
if (Request::is('*/locations/state/*')) {
            $router->bind('state', function ($id) {
                $state = $this->app->make('\Locations\Locations\Interfaces\StateRepositoryInterface');
                return $state->findorNew($id);
            });
        }

    }

    /**
     * Define the routes for the application.
     *
     * @param \Illuminate\Routing\Router $router
     *
     * @return void
     */
    public function map(Router $router)
    {
        $router->group(['namespace' => $this->namespace], function ($router) {
            require __DIR__ . '/../Http/routes.php';
        });
    }
}
